SecurityError

Enum SecurityError 

pub enum SecurityError {
    AuthorMismatch,
    InvalidAuthor,
    InvalidSignature,
    EncryptionFailed,
    DecryptionFailed,
    KeyDerivationFailed,
    RandomnessUnavailable,
    KeyProviderIo(String),
    InvalidKeyProviderData,
    InsecureKeyPermissions,
    CommitCodec(CommitCodecError),
}
Cryptographic validation or commit protection failure.

Variants



AuthorMismatch

The header author did not match the supplied endpoint signer.



InvalidAuthor

The encoded endpoint public key was invalid.



InvalidSignature

The commit signature was invalid.



EncryptionFailed

Authenticated encryption could not be completed.



DecryptionFailed

Ciphertext authentication or decryption failed.



KeyDerivationFailed

The commit sub-key could not be derived.



RandomnessUnavailable

The operating system random source was unavailable.



KeyProviderIo(String)

Local key-provider I/O failed without exposing key material.



InvalidKeyProviderData

Local key-provider bytes failed format or authentication checks.



InsecureKeyPermissions

Secret key files were accessible by group or other users.



CommitCodec(CommitCodecError)

The canonical commit representation was invalid.